@@ -1,8 +1,10 @@
 package Jifty::DBI;
-use warnings;
+use warnings; 
 use strict;
 
-$Jifty::DBI::VERSION = '0.39_999';
+
+our $VERSION = '0.06';
+
 
 =head1 NAME
 
@@ -13,7 +15,7 @@ Jifty::DBI - An object-relational persistence framework
 Jifty::DBI deals with databases, so that you don't have to.
 
 This module provides an object-oriented mechanism for retrieving and
-updating data in a DBI-accessible database. 
+updating data in a DBI-accesible database. 
 
 This module is the direct descendent of L<DBIx::SearchBuilder>. If you're familiar
 with SearchBuilder, Jifty::DBI should be quite familiar to you.
@@ -21,9 +23,9 @@ with SearchBuilder, Jifty::DBI should be quite familiar to you.
 =head2 What is it trying to do. 
 
 Jifty::DBI::Record abstracts the agony of writing the common and generally 
-simple SQL statements needed to serialize and de-serialize an object to the
+simple SQL statements needed to serialize and De-serialize an object to the
 database.  In a traditional system, you would define various methods on 
-your object 'create', 'read', 'update', and 'delete' being the most common. 
+your object 'create', 'readu', 'update', and 'delete' being the most common. 
 In each method you would have a SQL statement like: 
 
   select * from table where value='blah';
@@ -38,10 +40,10 @@ basically the same.
 
 Enter, Jifty::DBI::Record. 
 
-With ::Record, you can in the simple case, remove all of that code and 
-replace it by defining two methods and inheriting some code.  It's pretty 
-simple and incredibly powerful.  For more complex cases, you can 
-do more complicated things by overriding certain methods.  Let's stick with
+With::Record, you can in the simple case, remove all of that code and 
+replace it by defining two methods and inheriting some code.  Its pretty 
+simple, and incredibly powerful.  For more complex cases, you can, gasp, 
+do more complicated things by overriding certain methods.  Lets stick with
 the simple case for now. 
 
 
@@ -84,20 +86,22 @@ The table looks like so:
 
 First, let's define our record class in a new module named "Simple.pm".
 
+
   use warnings;
   use strict;
-
-  package Simple;
+   
+  package Simple::Schema;
   use Jifty::DBI::Schema;
-  use Jifty::DBI::Record schema {
-    column foo => type is 'text';
-    column bar => type is 'text';
-  };
+  
+  column foo => type is 'text';
+  column bar => type is 'text';
+  
+  package Simple; 
+  use base qw(Jifty::DBI::Record);
 
   # your custom code goes here.
 
   1;
-
 Like all perl modules, this needs to end with a true value. 
 
 Now, on to the code that will actually *do* something with this object. 
@@ -109,24 +113,24 @@ This code would be placed in your Perl script.
 Use two packages, the first is where I get the DB handle from, the latter 
 is the object I just created. 
 
-
+  
   my $handle = Jifty::DBI::Handle->new();
-  $handle->connect(
-      driver   => 'Pg',
-      database => 'test',
-      host     => 'reason',
-      user     => 'mhat',
-      password => ''
+  $handle->Connect(
+      Driver   => 'Pg',
+      Database => 'test',
+      Host     => 'reason',
+      User     => 'mhat',
+      Password => ''
   );
-
+  
 Creates a new Jifty::DBI::Handle, and then connects to the database using 
 that handle.  Pretty straight forward, the password '' is what I use 
 when there is no password.  I could probably leave it blank, but I find 
 it to be more clear to define it.
 
-
- my $s = Simple->new( handle => $handle );
-
+ 
+ my $s = Simple->new($handle);
+ 
  $s->load_by_cols(id=>1); 
 
 
@@ -134,7 +138,7 @@ it to be more clear to define it.
 
 =item load_by_cols
 
-Takes a hash of column => value pairs and returns the *first* to match. 
+Takes a hash of column =>value pairs and returns the *first* to match. 
 First is probably lossy across databases vendors. 
 
 =item load_from_hash
@@ -180,20 +184,20 @@ Currently Set<Field> updates the data in the database as soon as you call
 it.  In the future I hope to extend ::Record to better support transactional
 operations, such that updates will only happen when "you" say so.
 
-Finally, adding and removing records from the database.  ::Record provides a 
-Create method which simply takes a hash of key => value pairs.  The keys 
-exactly map to database columns. 
+Finally, adding a removing records from the database.  ::Record provides a 
+Create method which simply takes a hash of key=>value pairs.  The keys 
+exactly	map to database columns. 
 
  ## Get a new record object.
- $s1 = Simple->new( handle => $handle );
+ $s1 = Simple->new($handle);
  my ($id, $status_msg) = $s1->create(id  => 4,
-                   foo => 'Foooooo', 
-                   bar => 'Barrrrr');
+ 	           foo => 'Foooooo', 
+ 	           bar => 'Barrrrr');
 
 Poof! A new row in the database has been created!  Now lets delete the 
 object! 
 
- my $s2 = Simple->new( handle => $handle );
+ my $s2 = Simple->new($handle);
  $s2->load_by_cols(id=>4);
  $s2->delete();
 
