@@ -3,6 +3,7 @@ package Jifty::DBI::Collection;
 use warnings;
 use strict;
 
+
 =head1 NAME
 
 Jifty::DBI::Collection - Encapsulate SQL queries and rows in simple
@@ -52,9 +53,9 @@ use vars qw($VERSION);
 
 use Data::Page;
 use Clone;
-use Carp qw/croak/;
-use base qw/Class::Accessor::Fast/;
-__PACKAGE__->mk_accessors(qw/pager preload_columns preload_related/);
+use base qw/Class::Accessor/;
+__PACKAGE__->mk_accessors(qw/pager/);
+
 
 =head1 METHODS
 
@@ -100,19 +101,19 @@ sub _init {
         handle => undef,
         @_
     );
-    $self->_handle( $args{'handle'} ) if ( $args{'handle'} );
-    $self->table( $self->new_item->table() );
-    $self->clean_slate(%args);
+    $self->_handle( $args{'handle'} ) if ($args{'handle'});
+    $self->clean_slate();
 }
 
+
 sub _init_pager {
     my $self = shift;
-    $self->pager( Data::Page->new );
+    $self->pager(Data::Page->new);
 
     $self->pager->total_entries(0);
     $self->pager->entries_per_page(10);
     $self->pager->current_page(1);
-}
+} 
 
 =head2 clean_slate
 
@@ -125,7 +126,6 @@ cleaner to accomplish that in a different way, though.
 
 sub clean_slate {
     my $self = shift;
-    my %args = (@_);
     $self->redo_search();
     $self->_init_pager();
     $self->{'itemscount'}       = 0;
@@ -147,21 +147,21 @@ sub clean_slate {
         subclauses
         restrictions
         _open_parens
+        _close_parens
     );
 
-    $self->implicit_clauses(%args);
+    $self->implicit_clauses();
     $self->_is_limited(0);
-}
+} 
 
 =head2 implicit_clauses
 
 Called by L</clean_slate> to set up any implicit clauses that the
-collection B<always> has.  Defaults to doing nothing. Is passed the
-paramhash passed into L</new>.
+collection B<always> has.  Defaults to doing nothing.
 
 =cut
 
-sub implicit_clauses { }
+sub implicit_clauses {}
 
 =head2 _handle [DBH]
 
@@ -195,84 +195,15 @@ sub _do_search {
 
     my $records = $self->_handle->simple_query($query_string);
     return 0 unless $records;
-    my @names = @{ $records->{NAME_lc} };
-    my $data = {};
-    my $column_map = {};
-    foreach my $column (@names) {
-        if ($column =~ /^((\w+)_?(?:\d*))_(.*?)$/) {
-            $column_map->{$1}->{$2} =$column;
-        }
-    }
-    my @tables = keys %$column_map;
 
-
-    my @order;
-    while ( my $base_row = $records->fetchrow_hashref() ) {
-        my $main_pkey = $base_row->{$names[0]};
-        push @order, $main_pkey unless ( $order[0] && $order[-1] eq $main_pkey);
-
-            # let's chop the row into subrows;
-        foreach my $table (@tables) {
-            for ( keys %$base_row ) {
-                if ( $_ =~ /$table\_(.*)$/ ) {
-                    $data->{$main_pkey}->{$table} ->{ ($base_row->{ $table . '_id' } ||$main_pkey )}->{$1} = $base_row->{$_};
-                }
-            }
-        }
-
-    }
-
-    # For related "record" values, we can simply prepopulate the
-    # Jifty::DBI::Record cache and life will be good. (I suspect we want
-    # to do this _before_ doing the initial primary record load on the
-    # off chance that the primary record will try to do the relevant
-    # prefetch manually For related "collection" values, our job is a bit
-    # harder. we need to create a new empty collection object, set it's
-    # "must search" to 0 and manually add the records to it for each of
-    # the items we find. Then we need to ram it into place.
-
-    foreach my $row_id ( @order) {
-        my $item;
-        foreach my $row ( values %{ $data->{$row_id}->{'main'} } ) {
-            $item = $self->new_item();
-            $item->load_from_hash($row);
-        }
-        foreach my $alias ( grep { $_ ne 'main' } keys %{ $data->{$row_id} } ) {
-
-            my $related_rows = $data->{$row_id}->{$alias};
-            my ( $class, $col_name ) = $self->class_and_column_for_alias($alias);
-            if ($class) {
-
-            if ( $class->isa('Jifty::DBI::Collection') ) {
-                my $collection = $class->new( handle => $self->_handle );
-                foreach my $row( sort { $a->{id} <=> $b->{id} }  values %$related_rows ) {
-                    my $entry
-                        = $collection->new_item( handle => $self->_handle );
-                    $entry->load_from_hash($row);
-                    $collection->add_record($entry);
-                }
-
-                $item->_prefetched_collection( $col_name => $collection );
-            } elsif ( $class->isa('Jifty::DBI::Record') ) {
-                foreach my $related_row ( values %$related_rows ) {
-                    my $item = $class->new( handle => $self->_handle );
-                    $item->load_from_hash($related_row);
-                }
-            } else {
-                Carp::cluck(
-                    "Asked to preload $alias as a $class. Don't know how to handle $class"
-                );
-            }
-            }
-
-
-        }
+    while ( my $row = $records->fetchrow_hashref() ) {
+        my $item = $self->new_item();
+        $item->load_from_hash($row);
         $self->add_record($item);
+    }
+    return $self->_record_count if $records->err;
 
-    }
-    if ( $records->err ) {
-        $self->{'must_redo_search'} = 0;
-    }
+    $self->{'must_redo_search'} = 0;
 
     return $self->_record_count;
 }
@@ -281,17 +212,11 @@ sub _do_search {
 
 Adds a record object to this collection.
 
-This method automatically sets our "must redo search" flag to 0 and our "we have limits" flag to 1.
-
-Without those two flags, counting the number of items wouldn't work.
-
 =cut
 
 sub add_record {
     my $self   = shift;
     my $record = shift;
-    $self->_is_limited(1);
-    $self->{'must_redo_search'} = 0;
     push @{ $self->{'items'} }, $record;
 }
 
@@ -320,7 +245,7 @@ sub _do_count {
     my $all  = shift || 0;
 
     my $query_string = $self->build_select_count_query();
-    my $records      = $self->_handle->simple_query($query_string);
+    my $records     = $self->_handle->simple_query($query_string);
     return 0 unless $records;
 
     my @row = $records->fetchrow_array();
@@ -349,6 +274,10 @@ sub _apply_limits {
     $self->_handle->apply_limits( $statementref, $self->rows_per_page,
         $self->first_row );
 
+    # XXX TODO: refactor me, once we figure out the last place that columns could be set
+    $$statementref =~ s/main\.\*/CORE::join(', ', @{$self->{columns}})/eg
+        if $self->{columns}
+        and @{ $self->{columns} };
 }
 
 =head2 _distinct_query STATEMENTREF
@@ -362,7 +291,7 @@ is returned.
 sub _distinct_query {
     my $self         = shift;
     my $statementref = shift;
-    $self->_handle->distinct_query( $statementref, $self );
+    $self->_handle->distinct_query($statementref, $self);
 }
 
 =head2 _build_joins
@@ -387,9 +316,10 @@ together.
 
 sub _is_joined {
     my $self = shift;
-    if ( %{ $self->{'leftjoins'} } ) {
+    if ( keys( %{ $self->{'leftjoins'} } ) ) {
         return (1);
-    } else {
+    }
+    else {
         return ( @{ $self->{'aliases'} } );
     }
 
@@ -407,7 +337,8 @@ sub _limit_clause {
             $limit_clause .= $self->first_row . ", ";
         }
         $limit_clause .= $self->rows_per_page;
-    } else {
+    }
+    else {
         $limit_clause = "";
     }
     return $limit_clause;
@@ -424,7 +355,8 @@ sub _is_limited {
     my $self = shift;
     if (@_) {
         $self->{'is_limited'} = shift;
-    } else {
+    }
+    else {
         return ( $self->{'is_limited'} );
     }
 }
@@ -443,19 +375,18 @@ sub build_select_query {
 
     my $query_string = $self->_build_joins . " ";
 
-    if ( $self->_is_limited ) {
-        $query_string .= $self->_where_clause . " ";
+    if ( $self->_is_limited ) { 
+        $query_string .= $self->_where_clause . " "
     }
-    if ( $self->distinct_required ) {
-
-        # DISTINCT query only required for multi-table selects
-        $self->_distinct_query( \$query_string );
-    } else {
-        $query_string
-            = "SELECT " . $self->_preload_columns . " FROM $query_string";
+    if ( $self->_is_joined ) {
+     # DISTINCT query only required for multi-table selects
+        $self->_distinct_query(\$query_string);
+     } else {
+         $query_string = "SELECT main.* FROM $query_string";
         $query_string .= $self->_group_clause;
         $query_string .= $self->_order_clause;
-    }
+     }
+ 
 
     $self->_apply_limits( \$query_string );
 
@@ -463,138 +394,6 @@ sub build_select_query {
 
 }
 
-=head2 preload_columns
-
-The columns that the query would load for result items.  By default it's everything.
-
-XXX TODO: in the case of distinct, it needs to work as well.
-
-=cut
-
-sub _preload_columns {
-    my $self = shift;
-
-    my @cols            = ();
-    my $item            = $self->new_item;
-    if( $self->{columns} and @{ $self->{columns} } ) {
-         push @cols, @{$self->{columns}};
-         # push @cols, map { warn "Preloading $_"; "main.$_ as main_" . $_ } @{$preload_columns};
-    } else {
-        push @cols, $self->_qualified_record_columns( 'main' => $item );
-    }
-    my %preload_related = %{ $self->preload_related || {} };
-    foreach my $alias ( keys %preload_related ) {
-        my $related_obj = $preload_related{$alias};
-        if ( my $col_obj = $item->column($related_obj) ) {
-            my $reference_type = $col_obj->refers_to;
-
-            my $reference_item;
-
-            if ( !$reference_type ) {
-                Carp::cluck(
-                    "Asked to prefetch $col_obj->name for $self. But $col_obj->name isn't a known reference"
-                );
-            } elsif ( $reference_type->isa('Jifty::DBI::Collection') ) {
-                $reference_item = $reference_type->new->new_item();
-            } elsif ( $reference_type->isa('Jifty::DBI::Record') ) {
-                $reference_item = $reference_type->new;
-            } else {
-                Carp::cluck(
-                    "Asked to prefetch $col_obj->name for $self. But $col_obj->name isn't a known type"
-                );
-            }
-
-            push @cols,
-                $self->_qualified_record_columns( $alias => $reference_item );
-        }
-
-   #     push @cols, map { $_ . ".*" } keys %{ $self->preload_related || {} };
-
-    }
-    return CORE::join( ', ', @cols );
-}
-
-=head2 class_and_column_for_alias
-
-Takes the alias you've assigned to a prefetched related object. Returns the class
-of the column we've declared that alias preloads.
-
-=cut
-
-sub class_and_column_for_alias {
-    my $self            = shift;
-    my $alias           = shift;
-    my %preload_related = %{ $self->preload_related || {} };
-    my $related_colname = $preload_related{$alias};
-    if ( my $col_obj = $self->new_item->column($related_colname) ) {
-        return ( $col_obj->refers_to => $related_colname );
-    }
-    return undef;
-}
-
-sub _qualified_record_columns {
-    my $self  = shift;
-    my $alias = shift;
-    my $item  = shift;
-    grep {$_} map {
-        my $col = $_;
-        if ( $col->virtual ) {
-            undef;
-        } else {
-            $col = $col->name;
-            $alias . "." . $col . " as " . $alias . "_" . $col;
-        }
-    } $item->columns;
-}
-
-=head2  prefetch ALIAS_NAME ATTRIBUTE
-
-prefetches all related rows from alias ALIAS_NAME into the record attribute ATTRIBUTE of the
-sort of item this collection is.
-
-If you have employees who have many phone numbers, this method will let you search for all your employees
-    and prepopulate their phone numbers.
-
-Right now, in order to make this work, you need to do an explicit join between your primary table and the subsidiary tables AND then specify the name of the attribute you want to prefetch related data into.
-This method could be a LOT smarter. since we already know what the relationships between our tables are, that could all be precomputed.
-
-XXX TODO: in the future, this API should be extended to let you specify columns.
-
-=cut
-
-sub prefetch {
-    my $self           = shift;
-    my $alias          = shift;
-    my $into_attribute = shift;
-
-    my $preload_related = $self->preload_related() || {};
-
-    $preload_related->{$alias} = $into_attribute;
-
-    $self->preload_related($preload_related);
-
-}
-
-=head2 distinct_required
-
-Returns true if Jifty::DBI expects that this result set will end up
-with repeated rows and should be "condensed" down to a single row for
-each unique primary key.
-
-Out of the box, this method returns true if you've joined to another table.
-To add additional logic, feel free to override this method in your subclass.
-
-XXX TODO: it should be possible to create a better heuristic than the simple
-"is it joined?" question we're asking now. Something along the lines of "are we
-joining this table to something that is not the other table's primary key"
-
-=cut
-
-sub distinct_required {
-    my $self = shift;
-    return( $self->_is_joined ? 1 : 0 );
-}
-
 =head2 build_select_count_query
 
 Builds a SELECT statement to find the number of rows this collection
@@ -608,36 +407,20 @@ sub build_select_count_query {
     my $query_string = $self->_build_joins . " ";
 
     if ( $self->_is_limited ) {
-        $query_string .= $self->_where_clause . " ";
+        $query_string .= $self->_where_clause . " "
     }
 
     # DISTINCT query only required for multi-table selects
     if ( $self->_is_joined ) {
         $query_string = $self->_handle->distinct_count( \$query_string );
-    } else {
+    }
+    else {
         $query_string = "SELECT count(main.id) FROM " . $query_string;
     }
 
     return ($query_string);
 }
 
-=head2 do_search
-
-C<Jifty::DBI::Collection> usually does searches "lazily". That is, it
-does a C<SELECT COUNT> or a C<SELECT> on the fly the first time you ask
-for results that would need one or the other.  Sometimes, you need to
-display a count of results found before you iterate over a collection,
-but you know you're about to do that too. To save a bit of wear and tear
-on your database, call C<do_search> before that C<count>.
-
-=cut
-
-sub do_search {
-    my $self = shift;
-    $self->_do_search() if $self->{'must_redo_search'};
-
-}
-
 =head2 next
 
 Returns the next row from the set as an object of the type defined by
@@ -661,7 +444,8 @@ sub next {
         my $item = ( $self->{'items'}[ $self->{'itemscount'} ] );
         $self->{'itemscount'}++;
         return ($item);
-    } else {    #we've gone through the whole list. reset the count.
+    }
+    else {    #we've gone through the whole list. reset the count.
         $self->goto_first_item();
         return (undef);
     }
@@ -719,7 +503,7 @@ sub last {
 
 =head2 items_array_ref
 
-Return a reference to an array containing all objects found by this
+Return a refernece to an array containing all objects found by this
 search.
 
 =cut
@@ -746,7 +530,7 @@ sub new_item {
         unless $class;
 
     $class->require();
-    return $class->new( handle => $self->_handle );
+    return $class->new( $self->_handle );
 }
 
 =head2 record_class
@@ -756,13 +540,13 @@ to subclass.  Or, pass it the name of a class an an argument after
 creating a C<Jifty::DBI::Collection> object to create an 'anonymous'
 collection class.
 
-If you haven't specified a record class, this returns a best guess at
+If you haven't specified a record class, this eturns a best guess at
 the name of the record class for this collection.
 
 It uses a simple heuristic to determine the record class name -- It
 chops "Collection" off its own name. If you want to name your records
 and collections differently, go right ahead, but don't say we didn't
-warn you.
+warn you
 
 =cut
 
@@ -770,10 +554,10 @@ sub record_class {
     my $self = shift;
     if (@_) {
         $self->{record_class} = shift if (@_);
-    } elsif ( not $self->{record_class} ) {
+    }
+    elsif ( not $self->{record_class} ) {
         my $class = ref($self);
-        $class =~ s/Collection$//
-            or die "Can't guess record class from $class";
+        $class =~ s/Collection$// or die "Can't guess record class from $class";
         $self->{record_class} = $class;
     }
     return $self->{record_class};
@@ -795,21 +579,21 @@ sub redo_search {
 
 =head2 unlimit
 
-Clears all restrictions and causes this object to return all
+unlimit clears all restrictions and causes this object to return all
 rows in the primary table.
 
 =cut
 
 sub unlimit {
     my $self = shift;
-
+    
     $self->clean_slate();
     $self->_is_limited(-1);
 }
 
 =head2 limit
 
-Takes a hash of parameters with the following keys:
+limit takes a hash of parameters with the following keys:
 
 =over 4
 
@@ -828,11 +612,9 @@ criterias about the foreign table will be added.
 
 Column to be checked against.
 
-=item value
+=item VALUE
 
-Should always be set and will always be quoted.  If the value is a
-subclass of Jifty::DBI::Object, the value will be interpreted to be
-the object's id.
+Should always be set and will always be quoted. 
 
 =item operator
 
@@ -844,17 +626,12 @@ operator is the SQL operator to use for this phrase.  Possible choices include:
 
 =item "!="
 
-Any other standard SQL comparision operators that your underlying
-database supports are also valid.
-
 =item "LIKE"
 
+In the case of LIKE, the string is surrounded in % signs.  Yes. this is a bug.
+
 =item "NOT LIKE"
 
-=item "MATCHES"
-
-MATCHES is like LIKE, except it surrounds the value with % signs.
-
 =item "STARTSWITH"
 
 STARTSWITH is like LIKE, except it only appends a % at the end of the string
@@ -872,8 +649,7 @@ Can be AND or OR (or anything else valid to aggregate two clauses in SQL)
 =item case_sensitive
 
 on some databases, such as postgres, setting case_sensitive to 1 will make
-this search case sensitive.  Note that this flag is ignored if the column
-is numeric.
+this search case sensitive
 
 =back
 
@@ -898,15 +674,10 @@ sub limit {
     my ($Alias);
 
     # We need to be passed a column and a value, at very least
-    croak "Must provide a column to limit"
-        unless defined $args{column};
-    croak "Must provide a value to limit to"
-        unless defined $args{value};
-
-    # make passing in an object DTRT
-    if ( ref( $args{value} ) && $args{value}->isa('Jifty::DBI::Record') ) {
-        $args{value} = $args{value}->id;
-    }
+    die "Must provide a column to limit"
+      unless defined $args{column};
+    die "Must provide a value to limit to"
+      unless defined $args{value};
 
     #since we're changing the search criteria, we need to redo the search
     $self->redo_search();
@@ -916,13 +687,16 @@ sub limit {
         #If it's a like, we supply the %s around the search term
         if ( $args{'operator'} =~ /LIKE/i ) {
             $args{'value'} = $args{'value'};
-        } elsif ( $args{'operator'} =~ /MATCHES/i ) {
+        }
+        elsif ( $args{'operator'} =~ /MATCHES/i ) {
             $args{'value'}    = "%" . $args{'value'} . "%";
             $args{'operator'} = "LIKE";
-        } elsif ( $args{'operator'} =~ /STARTSWITH/i ) {
+        }
+        elsif ( $args{'operator'} =~ /STARTSWITH/i ) {
             $args{'value'}    = $args{'value'} . "%";
             $args{'operator'} = "LIKE";
-        } elsif ( $args{'operator'} =~ /ENDSWITH/i ) {
+        }
+        elsif ( $args{'operator'} =~ /ENDSWITH/i ) {
             $args{'value'}    = "%" . $args{'value'};
             $args{'operator'} = "LIKE";
         }
@@ -986,7 +760,8 @@ sub limit {
 
     if ( $args{'subclause'} ) {
         $Clause = $args{'subclause'};
-    } else {
+    }
+    else {
         $Clause = $qualified_column;
     }
 
@@ -1001,7 +776,8 @@ sub limit {
     if ( $args{'leftjoin'} ) {
         $restriction = \$self->{'leftjoins'}{ $args{'leftjoin'} }{'criteria'}
             {"$Clause"};
-    } else {
+    }
+    else {
         $restriction = \$self->{'restrictions'}{"$Clause"};
     }
 
@@ -1009,17 +785,17 @@ sub limit {
 
     if (   $self->_handle->case_sensitive
         && defined $args{'value'}
-        && $args{'quote_value'}
-        && !$args{'case_sensitive'} )
+        && $args{'value'} ne ''
+        && $args{'value'} ne "''"
+        && ( $args{'operator'} !~ /IS/ && $args{'value'} !~ /^null$/i ) )
     {
 
-        # don't worry about case for numeric columns_in_db
-        my $column_obj = $self->new_item()->column( $args{column} );
-        if ( defined $column_obj ? !$column_obj->is_numeric : 1 ) {
+        unless ( $args{'case_sensitive'} || !$args{'quote_value'} ) {
             ( $qualified_column, $args{'operator'}, $args{'value'} )
                 = $self->_handle->_make_clause_case_insensitive(
                 $qualified_column, $args{'operator'}, $args{'value'} );
         }
+
     }
 
     my $clause = "($qualified_column $args{'operator'} $args{'value'})";
@@ -1040,7 +816,8 @@ sub limit {
 
         $$restriction = $prefix . $clause;
 
-    } else {
+    }
+    else {
         $$restriction .= $args{'entry_aggregator'} . $prefix . $clause;
     }
 
@@ -1050,43 +827,25 @@ sub limit {
 
     if ( defined( $args{'alias'} ) ) {
         return ( $args{'alias'} );
-    } else {
+    }
+    else {
         return (1);
     }
 }
 
-=head2 open_paren CLAUSE
-
-Places an open paren at the current location in the given C<CLAUSE>.
-Note that this can be used for Deep Magic, and has a high likelyhood
-of allowing you to construct malformed SQL queries.  Its interface
-will probably change in the near future, but its presence allows for
-arbitrarily complex queries.
-
-=cut
-
-sub open_paren {
+sub _open_paren {
     my ( $self, $clause ) = @_;
     $self->{_open_parens}{$clause}++;
 }
 
-=head2 close_paren CLAUSE
-
-Places a close paren at the current location in the given C<CLAUSE>.
-Note that this can be used for Deep Magic, and has a high likelyhood
-of allowing you to construct malformed SQL queries.  Its interface
-will probably change in the near future, but its presence allows for
-arbitrarily complex queries.
-
-=cut
-
 # Immediate Action
-sub close_paren {
+sub _close_paren {
     my ( $self, $clause ) = @_;
     my $restriction = \$self->{'restrictions'}{"$clause"};
     if ( !$$restriction ) {
         $$restriction = " ) ";
-    } else {
+    }
+    else {
         $$restriction .= " ) ";
     }
 }
@@ -1101,8 +860,8 @@ sub _add_subclause {
 }
 
 sub _where_clause {
-    my $self         = shift;
-    my $where_clause = '';
+    my $self = shift;
+    my  $where_clause = '';
 
     # Go through all the generic restrictions and build up the
     # "generic_restrictions" subclause.  That's the only one that the
@@ -1112,14 +871,13 @@ sub _where_clause {
 
     #Go through all restriction types. Build the where clause from the
     #Various subclauses.
-
+    
     my @subclauses;
-    foreach my $subclause ( sort keys %{ $self->{'subclauses'} } ) {
+    foreach my $subclause ( keys %{ $self->{'subclauses'} } ) {
         push @subclauses, $self->{'subclauses'}{"$subclause"};
     }
 
-    $where_clause = " WHERE " . CORE::join( ' AND ', @subclauses )
-        if (@subclauses);
+    $where_clause = " WHERE " . join ( ' AND ', @subclauses) if ( @subclauses  );
 
     return ($where_clause);
 
@@ -1186,24 +944,21 @@ Use array of hashes to order by many columns/functions.
 
 The results would be unordered if method called without arguments.
 
-Returns the current list of columns.
-
 =cut
 
 sub order_by {
-    my $self = shift;
-    if (@_) {
-        my @args = @_;
-
-        unless ( UNIVERSAL::isa( $args[0], 'HASH' ) ) {
-            @args = {@args};
-        }
-        $self->{'order_by'} = \@args;
-        $self->redo_search();
+     my $self = shift;
+     my @args = @_;
+ 
+    unless ( UNIVERSAL::isa( $args[0], 'HASH' ) ) {
+        @args = {@args};
     }
-    return ( $self->{'order_by'} || []);
+    $self->{'order_by'} = \@args;
+    $self->redo_search();
 }
 
+
+
 =head2 _order_clause
 
 returns the ORDER BY clause for the search.
@@ -1216,7 +971,7 @@ sub _order_clause {
     return '' unless $self->{'order_by'};
 
     my $clause = '';
-    foreach my $row ( @{ $self->{'order_by'} } ) {
+    foreach my $row ( @{$self->{'order_by'}} ) {
 
         my %rowhash = (
             alias  => 'main',
@@ -1226,21 +981,23 @@ sub _order_clause {
         );
         if ( $rowhash{'order'} =~ /^des/i ) {
             $rowhash{'order'} = "DESC";
-        } else {
+        }
+        else {
             $rowhash{'order'} = "ASC";
         }
 
         if ( $rowhash{'function'} ) {
             $clause .= ( $clause ? ", " : " " );
-            $clause .= $rowhash{'function'} . ' ';
+            $clause .= $rowhash{'function'};
             $clause .= $rowhash{'order'};
 
-        } elsif ( (defined $rowhash{'alias'} )
+        }
+        elsif ( ( $rowhash{'alias'} )
             and ( $rowhash{'column'} ) )
         {
 
             $clause .= ( $clause ? ", " : " " );
-            $clause .= $rowhash{'alias'} . "." if $rowhash{'alias'};
+            $clause .= $rowhash{'alias'} . ".";
             $clause .= $rowhash{'column'} . " ";
             $clause .= $rowhash{'order'};
         }
@@ -1249,6 +1006,7 @@ sub _order_clause {
     return $clause;
 }
 
+
 =head2 group_by_cols DEPRECATED
 
 *DEPRECATED*. Use group_by method.
@@ -1292,6 +1050,7 @@ sub group_by {
     $self->redo_search();
 }
 
+
 =head2 _group_clause
 
 Private function to return the "GROUP BY" clause for this query.
@@ -1302,12 +1061,13 @@ sub _group_clause {
     my $self = shift;
     return '' unless $self->{'group_by'};
 
-    my $row;
-    my $clause;
+     my $row;
+     my $clause;
+ 
+    foreach $row ( @{$self->{'group_by'}} ) {
+         my %rowhash = ( alias => 'main',
+
 
-    foreach $row ( @{ $self->{'group_by'} } ) {
-        my %rowhash = (
-            alias => 'main',
 
             column => undef,
             %$row
@@ -1316,7 +1076,8 @@ sub _group_clause {
             $clause .= ( $clause ? ", " : " " );
             $clause .= $rowhash{'function'};
 
-        } elsif ( ( $rowhash{'alias'} )
+        }
+        elsif ( ( $rowhash{'alias'} )
             and ( $rowhash{'column'} ) )
         {
 
@@ -1325,11 +1086,12 @@ sub _group_clause {
             $clause .= $rowhash{'column'};
         }
     }
-    if ($clause) {
-        return " GROUP BY" . $clause . " ";
-    } else {
-        return '';
-    }
+     if ($clause) {
+	return " GROUP BY" . $clause . " ";
+     }
+     else {
+	return '';
+     }
 }
 
 =head2 new_alias table_OR_CLASS
@@ -1348,7 +1110,8 @@ sub new_alias {
 
     if ( $refers_to->can('table') ) {
         $table = $refers_to->table;
-    } else {
+    }
+    else {
         $table = $refers_to;
     }
 
@@ -1387,13 +1150,13 @@ $self->new_alias or a $self->limit. C<column1> and C<column2> are the columns
 in C<alias1> and C<alias2> that should be linked, respectively.  For this
 type of join, this method has no return value.
 
-Supplying the parameter C<type> => 'left' causes Join to perform a left
+Supplying the parameter C<type> => 'left' causes Join to preform a left
 join.  in this case, it takes C<alias1>, C<column1>, C<table2> and
 C<column2>. Because of the way that left joins work, this method needs a
 table for the second column rather than merely an alias.  For this type
 of join, it will return the alias generated by the join.
 
-The parameter C<operator> defaults C<=>, but you can specify other
+The parameter C<operator> defaults C<=>, but you can specity other
 operators to join with.
 
 Instead of C<alias1>/C<column1>, it's possible to specify expression, to join
@@ -1417,6 +1180,7 @@ sub join {
 
 }
 
+
 =head2 set_page_info [per_page => NUMBER,] [current_page => NUMBER]
 
 Sets the current page (one-based) and number of items per page on the
@@ -1429,22 +1193,23 @@ the selected page.
 =cut
 
 sub set_page_info {
-    my $self = shift;
-    my %args = (
-        per_page     => undef,
-        current_page => undef,    # 1-based
-        @_
-    );
-
-    $self->pager->total_entries( $self->count_all )
-        ->entries_per_page( $args{'per_page'} )
-        ->current_page( $args{'current_page'} );
-
-    $self->rows_per_page( $args{'per_page'} );
-    $self->first_row( $self->pager->first || 1 );
-
+  my $self = shift;
+  my %args = (
+    per_page => undef,
+    current_page => undef, # 1-based
+    @_
+  );
+  
+  $self->pager->total_entries($self->count_all)
+              ->entries_per_page($args{'per_page'})
+              ->current_page($args{'current_page'});
+  
+  $self->rows_per_page($args{'per_page'});
+  $self->first_row($self->pager->first);
+  
 }
 
+
 =head2 rows_per_page
 
 limits the number of rows returned by the database.  Optionally, takes
@@ -1589,7 +1354,8 @@ sub is_last {
 
     if ( $self->_items_counter == $self->count ) {
         return (1);
-    } else {
+    }
+    else {
         return (0);
     }
 }
@@ -1602,38 +1368,13 @@ sub DEBUG {
     return ( $self->{'DEBUG'} );
 }
 
-=head2 column
+=head2 column { column => undef } 
 
-Normally a collection object contains record objects populated with all columns
-in the database, but you can restrict the records to only contain some
-particular columns, by calling the C<column> method once for each column you
-are interested in.
+Specify that we want to load the column  column. 
 
-Takes a hash of parameters; the C<column>, C<table> and C<alias> keys means
-the same as in the C<limit> method.  A special C<function> key may contain
-one of several possible kinds of expressions:
+Other parameters are table alias AND function.
 
-=over 4
-
-=item C<DISTINCT COUNT>
-
-Same as C<COUNT(DISTINCT ?)>.
-
-=item Expression with C<?> in it
-
-The C<?> is substituted with the column name, then passed verbatim to the
-underlying C<SELECT> statement.
-
-=item Expression with C<(> in it
-
-The expression is passed verbatim to the underlying C<SELECT>.
-
-=item Any other expression
-
-The expression is taken to be a function name.  For example, C<SUM> means
-the same thing as C<SUM(?)>.
-
-=back
+Autrijus and Ruslan owe docs.
 
 =cut
 
@@ -1651,7 +1392,8 @@ sub column {
         if ( my $alias = $args{alias} ) {
             $alias =~ s/_\d+$//;
             $alias;
-        } else {
+        }
+        else {
             $self->table;
         }
     };
@@ -1664,13 +1406,14 @@ sub column {
 
         # If we want to substitute
         elsif ( $func =~ /\?/ ) {
-            $name =~ s/\?/$name/g;
+            $name = CORE::join( $name, split( /\?/, $func ) );
         }
 
         # If we want to call a simple function on the column
         elsif ( $func !~ /\(/ ) {
             $name = "\U$func\E($name)";
-        } else {
+        }
+        else {
             $name = $func;
         }
 
@@ -1678,14 +1421,13 @@ sub column {
 
     my $column = "col" . @{ $self->{columns} ||= [] };
     $column = $args{column} if $table eq $self->table and !$args{alias};
-    $column = ($args{'alias'}||'main')."_".$column;
     push @{ $self->{columns} }, "$name AS \L$column";
     return $column;
 }
 
 =head2 columns LIST
 
-Specify that we want to load only the columns in LIST, which is a 
+Specify that we want to load only the columns in LIST
 
 =cut
 
@@ -1735,7 +1477,7 @@ sub has_column {
         @_
     );
 
-    my $table  = $args{table}  or die;
+    my $table = $args{table}  or die;
     my $column = $args{column} or die;
     return grep { $_ eq $column } $self->columns_in_db($table);
 }
@@ -1754,21 +1496,36 @@ sub table {
     return $self->{table};
 }
 
-=head2 clone
+=head2 refers_to
+
+Private convenience method needed for the declarative schema generation.
+
+=cut
+
+sub refers_to (@) {
+    my $class = shift;
+    my (%args) = @_;
+
+    return ( refers_to => $class, %args );
+}
+
+
+=head2 Clone
 
 Returns copy of the current object with all search restrictions.
 
 =cut
 
-sub clone {
+sub clone
+{
     my $self = shift;
 
     my $obj = bless {}, ref($self);
     %$obj = %$self;
 
-    $obj->redo_search();    # clean out the object of data
-
-    $obj->{$_} = Clone::clone( $obj->{$_} ) for ( $self->_cloned_attributes );
+    $obj->redo_search(); # clean out the object of data
+    
+    $obj->{$_} = Clone::clone($obj->{$_}) for ( $self->_cloned_attributes );
     return $obj;
 }
 
@@ -1781,16 +1538,18 @@ clonning then you probably want override this method and add own values to
 the list.
 
 =cut
-
-sub _cloned_attributes {
+ 
+sub _cloned_attributes
+{
     return qw(
         aliases
         left_joins
         subclauses
         restrictions
     );
-}
-
+ }
+ 
+ 
 1;
 __END__
 
