@@ -21,7 +21,7 @@ compensates for some of the idiosyncrasies of ODBC.
 
 =cut
 
-=head2 case_sensitive
+=head2 CaseSensitive
 
 Returns a false value.
 
@@ -32,30 +32,30 @@ sub case_sensitive {
     return (undef);
 }
 
-=head2 build_dsn
+=head2 BuildDSN
 
 =cut
 
 sub build_dsn {
     my $self = shift;
     my %args = (
-        driver     => undef,
-        database   => undef,
-        host       => undef,
-        port       => undef,
+        Driver   => undef,
+        Database => undef,
+        Host     => undef,
+        Port     => undef,
         @_
     );
 
-    $args{dbname} ||= delete $args{database};
-
-    my $dsn = "dbi:$args{driver}:$args{dbname}";
-    $dsn .= ";host=$args{'host'}" if $args{'host'};
-    $dsn .= ";port=$args{'port'}" if $args{'port'};
+    my $dsn = "dbi:$args{'Driver'}:$args{'Database'}";
+    $dsn .= ";host=$args{'Host'}"
+        if ( defined $args{'Host'} && $args{'Host'} );
+    $dsn .= ";port=$args{'Port'}"
+        if ( defined $args{'Port'} && $args{'Port'} );
 
     $self->{'dsn'} = $dsn;
 }
 
-=head2 apply_limits
+=head2 ApplyLimits
 
 =cut
 
@@ -70,7 +70,7 @@ sub apply_limits {
     $$statementref =~ s/SELECT\b/SELECT $limit_clause/;
 }
 
-=head2 distinct_query
+=head2 DistinctQuery
 
 =cut
 
@@ -79,16 +79,12 @@ sub distinct_query {
     my $statementref = shift;
 
     my $sb = shift;
-
-    $$statementref = "SELECT main.* FROM $$statementref";
+ 
+     $$statementref = "SELECT main.* FROM $$statementref";
     $$statementref .= $sb->_group_clause;
     $$statementref .= $sb->_order_clause;
 }
 
-=head2 encoding
-
-=cut
-
 sub encoding {
 }
 
@@ -98,7 +94,7 @@ __END__
 
 =head1 AUTHOR
 
-Audrey Tang C<cpan@audreyt.org>
+Autrijus Tang
 
 =head1 SEE ALSO
 
